****** Column Summary ******

1. Number of columns in common with matching schemas: {0}
1. Number of columns in common with schema differences: {1}
1. Number of columns in base but not compare: {2}
1. Number of columns in compare but not base: {3}